Stan Math Library: stan/math/prim/mat/fun/positive_ordered_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
positive_ordered_constrain.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::positive_ordered_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x)
| Return an increasing positive ordered vector derived from the specified free vector. More...
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::positive_ordered_constrain (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &x, T &lp)
| Return a positive valued, increasing positive ordered vector derived from the specified free vector and increment the specified log probability reference with the log absolute Jacobian determinant of the transform. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.